# python-CLI
Este es el CLI de python para HostHome

# Como usarlo
```sh
C:\> pip install HostHome-cli
...
C:\> hosthome -v
...
C:\> hosthome empezar # Y se creara tu archivo
```

### Lenguages admitidos

* ruby, python, nodejs, scala, clojure, cs, php)
